#!/usr/bin/env python

import argparse
from typing import Iterable

import boto3
from botocore.config import Config

logs_client = boto3.client("logs", config=Config(retries={"mode": "standard"}))


def get_log_streams(log_group_name: str) -> Iterable[str]:
    params = {"logGroupName": log_group_name}
    while True:
        res = logs_client.describe_log_streams(**params)
        for stream in res["logStreams"]:
            yield stream["logStreamName"]
        if "nextToken" not in res:
            break
        params["nextToken"] = res["nextToken"]


def stream_has_no_events(log_group_name: str, log_stream_name: str):
    res = logs_client.get_log_events(logGroupName=log_group_name, logStreamName=log_stream_name, limit=1)
    return len(res["events"]) == 0


def get_empty_streams(log_group_name: str) -> Iterable[str]:
    yield from filter(lambda x: stream_has_no_events(log_group_name, x), get_log_streams(log_group_name))


def delete_empty_streams(log_group_name: str, dry_run: bool):
    for log_stream_name in get_empty_streams(log_group_name):
        print(log_stream_name)
        if not dry_run:
            logs_client.delete_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--log-group-name", required=True)
    parser.add_argument("-n", "--dry-run", action="store_true")
    args = parser.parse_args()

    delete_empty_streams(args.log_group_name, args.dry_run)


if __name__ == "__main__":
    main()
